@@ -1,8 +1,10 @@
 //! Configuration module
 
 mod prima;
+mod test;
 
 pub use prima::{Environment, PrimaConfiguration};
+pub use test::TestConfiguration;
 
 /// A trait representing a valid configuration entity
 pub trait Configuration {
